@@ -12,29 +12,37 @@ from typing import Any, List, Optional
 import numpy as np
 import pandas as pd
 
-from responsibleai._input_processing import _convert_to_list
+from raiutils.data_processing import convert_to_list
+from raiutils.models import SKLearn, is_classifier
 from responsibleai._interfaces import Dataset, RAIInsightsData
-from responsibleai._internal.constants import ManagerNames, Metadata, SKLearn
+from responsibleai._internal.constants import ManagerNames, Metadata
 from responsibleai.exceptions import UserConfigValidationException
 from responsibleai.managers.causal_manager import CausalManager
 from responsibleai.managers.counterfactual_manager import CounterfactualManager
+from responsibleai.managers.data_balance_manager import DataBalanceManager
 from responsibleai.managers.error_analysis_manager import ErrorAnalysisManager
 from responsibleai.managers.explainer_manager import ExplainerManager
 from responsibleai.rai_insights.constants import ModelTask
 from responsibleai.rai_insights.rai_base_insights import RAIBaseInsights
-from responsibleai.utils import _is_classifier
 
 _PREDICTIONS = 'predictions'
 _TRAIN = 'train'
 _TARGET_COLUMN = 'target_column'
 _TASK_TYPE = 'task_type'
 _CLASSES = 'classes'
+_FEATURE_COLUMNS = 'feature_columns'
+_FEATURE_RANGES = 'feature_ranges'
 _CATEGORICAL_FEATURES = 'categorical_features'
 _META_JSON = Metadata.META_JSON
 _TRAIN_LABELS = 'train_labels'
 _JSON_EXTENSION = '.json'
 _PREDICT = 'predict'
 _PREDICT_PROBA = 'predict_proba'
+_COLUMN_NAME = 'column_name'
+_RANGE_TYPE = 'range_type'
+_UNIQUE_VALUES = 'unique_values'
+_MIN_VALUE = 'min_value'
+_MAX_VALUE = 'max_value'
 
 
 class RAIInsights(RAIBaseInsights):
@@ -92,12 +100,19 @@ class RAIInsights(RAIBaseInsights):
             target_column=target_column,
             classes=classes
         )
+        self._feature_columns = \
+            test.drop(columns=[target_column]).columns.tolist()
+        self._feature_ranges = RAIInsights._get_feature_ranges(
+            test=test, categorical_features=categorical_features,
+            feature_columns=self._feature_columns)
         self.categorical_features = categorical_features
 
         super(RAIInsights, self).__init__(
             model, train, test, target_column, task_type,
             serializer)
 
+        self._try_add_data_balance()
+
     def _initialize_managers(self):
         """Initializes the managers.
 
@@ -113,6 +128,10 @@ class RAIInsights(RAIBaseInsights):
             target_column=self.target_column, task_type=self.task_type,
             categorical_features=self.categorical_features)
 
+        self._data_balance_manager = DataBalanceManager(
+            train=self.train, test=self.test, target_column=self.target_column,
+            classes=self._classes, task_type=self.task_type)
+
         self._error_analysis_manager = ErrorAnalysisManager(
             self.model, self.test, self.target_column,
             self._classes,
@@ -126,6 +145,7 @@ class RAIInsights(RAIBaseInsights):
 
         self._managers = [self._causal_manager,
                           self._counterfactual_manager,
+                          self._data_balance_manager,
                           self._error_analysis_manager,
                           self._explainer_manager]
 
@@ -142,6 +162,17 @@ class RAIInsights(RAIBaseInsights):
         else:
             return None
 
+    def _try_add_data_balance(self):
+        """
+        Add data balance measures to be computed on categorical features
+        if it is a classification task.
+        """
+        if self.task_type == ModelTask.CLASSIFICATION and \
+                len(self.categorical_features) > 0 and \
+                self._classes is not None:
+            self._data_balance_manager.add(
+                cols_of_interest=self.categorical_features)
+
     def _validate_rai_insights_input_parameters(
             self, model: Any, train: pd.DataFrame, test: pd.DataFrame,
             target_column: str, task_type: str,
@@ -404,8 +435,10 @@ class RAIInsights(RAIBaseInsights):
         dashboard_dataset = Dataset()
         dashboard_dataset.task_type = self.task_type
         dashboard_dataset.categorical_features = self.categorical_features
-        dashboard_dataset.class_names = _convert_to_list(
+        dashboard_dataset.class_names = convert_to_list(
             self._classes)
+        dashboard_dataset.data_balance_measures = \
+            self._data_balance_manager.get_data()
 
         predicted_y = None
         feature_length = None
@@ -416,7 +449,7 @@ class RAIInsights(RAIBaseInsights):
         if isinstance(dataset, pd.DataFrame) and hasattr(dataset, 'columns'):
             self._dataframeColumns = dataset.columns
         try:
-            list_dataset = _convert_to_list(dataset)
+            list_dataset = convert_to_list(dataset)
         except Exception as ex:
             raise ValueError(
                 "Unsupported dataset type") from ex
@@ -428,7 +461,7 @@ class RAIInsights(RAIBaseInsights):
                 "dataset type"
                 raise ValueError(msg) from ex
             try:
-                predicted_y = _convert_to_list(predicted_y)
+                predicted_y = convert_to_list(predicted_y)
             except Exception as ex:
                 raise ValueError(
                     "Model prediction output of unsupported type,") from ex
@@ -461,26 +494,26 @@ class RAIInsights(RAIBaseInsights):
                dashboard_dataset.class_names is not None):
                 true_y = [dashboard_dataset.class_names.index(
                     y) for y in true_y]
-            dashboard_dataset.true_y = _convert_to_list(true_y)
+            dashboard_dataset.true_y = convert_to_list(true_y)
 
         features = dataset.columns
 
         if features is not None:
-            features = _convert_to_list(features)
+            features = convert_to_list(features)
             if feature_length is not None and len(features) != feature_length:
                 raise ValueError("Feature vector length mismatch:"
                                  " feature names length differs"
                                  " from local explanations dimension")
             dashboard_dataset.feature_names = features
         dashboard_dataset.target_column = self.target_column
-        if _is_classifier(self.model) and dataset is not None:
+        if is_classifier(self.model) and dataset is not None:
             try:
                 probability_y = self.model.predict_proba(dataset)
             except Exception as ex:
                 raise ValueError("Model does not support predict_proba method"
                                  " for given dataset type,") from ex
             try:
-                probability_y = _convert_to_list(probability_y)
+                probability_y = convert_to_list(probability_y)
             except Exception as ex:
                 raise ValueError(
                     "Model predict_proba output of unsupported type,") from ex
@@ -523,16 +556,41 @@ class RAIInsights(RAIBaseInsights):
         :type path: str
         """
         top_dir = Path(path)
-        classes = _convert_to_list(self._classes)
+        classes = convert_to_list(self._classes)
         meta = {
             _TARGET_COLUMN: self.target_column,
             _TASK_TYPE: self.task_type,
             _CATEGORICAL_FEATURES: self.categorical_features,
-            _CLASSES: classes
+            _CLASSES: classes,
+            _FEATURE_COLUMNS: self._feature_columns,
+            _FEATURE_RANGES: self._feature_ranges
+
         }
         with open(top_dir / _META_JSON, 'w') as file:
             json.dump(meta, file)
 
+    @staticmethod
+    def _get_feature_ranges(test, categorical_features, feature_columns):
+        """Get feature ranges like min, max and unique values
+        for all columns"""
+        result = []
+        for col in feature_columns:
+            res_object = {}
+            if (col in categorical_features):
+                unique_value = test[col].unique()
+                res_object[_COLUMN_NAME] = col
+                res_object[_RANGE_TYPE] = "categorical"
+                res_object[_UNIQUE_VALUES] = unique_value.tolist()
+            else:
+                min_value = float(test[col].min())
+                max_value = float(test[col].max())
+                res_object[_COLUMN_NAME] = col
+                res_object[_RANGE_TYPE] = "integer"
+                res_object[_MIN_VALUE] = min_value
+                res_object[_MAX_VALUE] = max_value
+            result.append(res_object)
+        return result
+
     @staticmethod
     def _load_metadata(inst, path):
         """Load the metadata.
@@ -562,6 +620,9 @@ class RAIInsights(RAIBaseInsights):
             classes=classes
         )
 
+        inst.__dict__['_' + _FEATURE_COLUMNS] = meta[_FEATURE_COLUMNS]
+        inst.__dict__['_' + _FEATURE_RANGES] = meta[_FEATURE_RANGES]
+
     @staticmethod
     def load(path):
         """Load the RAIInsights from the given path.
@@ -578,6 +639,7 @@ class RAIInsights(RAIBaseInsights):
         manager_map = {
             ManagerNames.CAUSAL: CausalManager,
             ManagerNames.COUNTERFACTUAL: CounterfactualManager,
+            ManagerNames.DATA_BALANCE: DataBalanceManager,
             ManagerNames.ERROR_ANALYSIS: ErrorAnalysisManager,
             ManagerNames.EXPLAINER: ExplainerManager,
         }
