@@ -6,13 +6,15 @@ import pandas as pd
 import pytest
 from econml.solutions.causal_analysis._causal_analysis import CausalAnalysis
 
+from responsibleai import ModelTask
 from responsibleai._interfaces import (CausalConfig, CausalData, CausalPolicy,
                                        CausalPolicyGains,
                                        CausalPolicyTreeInternal,
                                        CausalPolicyTreeLeaf)
+from responsibleai._internal.constants import (CausalManagerKeys,
+                                               ListProperties, ManagerNames)
 from responsibleai._tools.causal.causal_result import CausalResult
 from responsibleai.exceptions import UserConfigValidationException
-from responsibleai import ModelTask
 
 EFFECTS_ATTRIBUTES = [
     'point',
@@ -36,13 +38,15 @@ def validate_causal(rai_insights, data, target_column,
                     treatment_features, max_cat_expansion):
     if rai_insights.task_type == ModelTask.CLASSIFICATION and \
             len(np.unique(data[target_column])) > 2:
-        with pytest.raises(AssertionError,
+        with pytest.raises(UserConfigValidationException,
                            match="Multiclass classification isn't supported"):
             rai_insights.causal.add(
                 treatment_features,
                 nuisance_model='automl',
                 upper_bound_on_cat_expansion=max_cat_expansion)
             rai_insights.causal.compute()
+        _check_causal_properties(rai_insights.causal.list(),
+                                 expected_causal_effects=0)
         return
 
     # Add the first configuration
@@ -50,6 +54,7 @@ def validate_causal(rai_insights, data, target_column,
         treatment_features,
         nuisance_model='automl',
         upper_bound_on_cat_expansion=max_cat_expansion)
+    rai_insights.compute()
 
     results = rai_insights.causal.get()
     assert results is not None
@@ -57,6 +62,9 @@ def validate_causal(rai_insights, data, target_column,
     assert len(results) == 1
     _check_causal_result(results[0])
 
+    _check_causal_properties(rai_insights.causal.list(),
+                             expected_causal_effects=1)
+
     results = rai_insights.causal.get_data()
     assert results is not None
     assert isinstance(results, list)
@@ -66,16 +74,41 @@ def validate_causal(rai_insights, data, target_column,
     # Add the second configuration
     rai_insights.causal.add(treatment_features,
                             nuisance_model='linear')
+    rai_insights.compute()
     results = rai_insights.causal.get()
     assert results is not None
     assert isinstance(results, list)
     assert len(results) == 2
 
-    # Add a bad configuration
+    _check_causal_properties(rai_insights.causal.list(),
+                             expected_causal_effects=2)
+
+    # Add a bad configuration for nuisance_model
     with pytest.raises(UserConfigValidationException):
         rai_insights.causal.add(treatment_features,
                                 nuisance_model='fake_model')
 
+    # Add a bad configuration for heterogeneity_model
+    with pytest.raises(UserConfigValidationException):
+        rai_insights.causal.add(treatment_features,
+                                heterogeneity_model='fake_model')
+
+
+def _check_causal_properties(
+        causal_props, expected_causal_effects):
+    assert causal_props[ListProperties.MANAGER_TYPE] == \
+        ManagerNames.CAUSAL
+    assert causal_props[
+        CausalManagerKeys.CAUSAL_EFFECTS] is not None
+    assert len(
+        causal_props[CausalManagerKeys.CAUSAL_EFFECTS]) == \
+        expected_causal_effects
+
+    for causal_effect in causal_props[CausalManagerKeys.CAUSAL_EFFECTS]:
+        assert causal_effect['global_effects_computed']
+        assert causal_effect['local_effects_computed']
+        assert causal_effect['policies_computed']
+
 
 def _check_causal_result(causal_result, is_serialized=False):
     assert len(causal_result.id) > 0
